@@ -8,7 +8,7 @@ import optparse
 
 try:
   import rrdtool
-except ImportError, exc:
+except ImportError as exc:
   raise SystemExit('[ERROR] Missing dependency: %s' % str(exc))
 
 try:
@@ -38,6 +38,11 @@ option_parser.add_option(
     ', '.join(aggregationMethods),
     default='average',
     type='string')
+option_parser.add_option('--destinationPath', 
+    help="Path to place created whisper file. Defaults to the " + 
+    "RRD file's source path.",
+    default=None,
+    type='string')
 
 (options, args) = option_parser.parse_args()
 
@@ -49,7 +54,7 @@ rrd_path = args[0]
 
 try:
   rrd_info = rrdtool.info(rrd_path)
-except rrdtool.error, exc:
+except rrdtool.error as exc:
   raise SystemExit('[ERROR] %s' % str(exc))
 
 seconds_per_pdp = rrd_info['step']
@@ -75,9 +80,8 @@ else:
     rra_info['xff'] = rrd_info['rra[%d].xff' % i]
     rras.append(rra_info)
 
-datasources = []
 if 'ds' in rrd_info:
-  datasource_names = rrd_info['ds'].keys()
+  datasources = rrd_info['ds'].keys()
 else:
   ds_keys = [key for key in rrd_info if key.startswith('ds[')]
   datasources = list(set(key[3:].split(']')[0] for key in ds_keys))
@@ -104,16 +108,31 @@ for rra in relevant_rras:
 
 for datasource in datasources:
   now = int(time.time())
-  path = rrd_path.replace('.rrd', '_%s.wsp' % datasource)
+  suffix = '_%s' % datasource if len(datasources) > 1 else ''
+
+  if options.destinationPath:
+    destination_path = options.destinationPath
+    if not os.path.isdir(destination_path):
+      try:
+        os.makedirs(destination_path)
+      except OSError as exc: # Python >2.5
+        if exc.errno == errno.EEXIST and os.path.isdir(destination_path):
+          pass
+        else: raise
+    rrd_file = os.path.basename(rrd_path).replace('.rrd', '%s.wsp' % suffix)
+    path = destination_path + '/' + rrd_file
+  else:
+    path = rrd_path.replace('.rrd', '%s.wsp' % suffix)
+
   try:
     whisper.create(path, archives, xFilesFactor=xFilesFactor)
-  except whisper.InvalidConfiguration, e:
+  except whisper.InvalidConfiguration as e:
     raise SystemExit('[ERROR] %s' % str(e))
   size = os.stat(path).st_size
   archiveConfig = ','.join(["%d:%d" % ar for ar in archives])
-  print "Created: %s (%d bytes) with archives: %s" % (path, size, archiveConfig)
+  print("Created: %s (%d bytes) with archives: %s" % (path, size, archiveConfig))
 
-  print "Migrating data"
+  print("Migrating data")
   archiveNumber = len(archives) - 1
   for precision, points in reversed(archives):
     retention = precision * points
@@ -132,6 +151,6 @@ for datasource in datasources:
     timestamps = list(range(*time_info))
     datapoints = zip(timestamps, values)
     datapoints = filter(lambda p: p[1] is not None, datapoints)
-    print ' migrating %d datapoints from archive %d' % (len(datapoints), archiveNumber)
+    print(' migrating %d datapoints from archive %d' % (len(datapoints), archiveNumber))
     archiveNumber -= 1
     whisper.update_many(path, datapoints)
